=======
History
=======

0.1.1 (2016-10-14)
------------------

* Minor improvements to README.rst for better presentation on pypi

0.1.0 (2016-10-04)
------------------

* Initial release with single script mpidir.py
